phyloTop-package: Phylogenetic Tree Topological Properties Evaluator
Description
Calculates some topological properties of phylogenetic trees.Details
ll{
Package: phyloTop
Type: Package
Version: 1.1
Date: 2013-10-05
License: GPL-2
}
This package is based on the package phylobase. See its documentation for many useful related functions. In particular nodeId and treewalk. library(help=phyloTop) will give more information on the package.
Many thanks to Caroline Colijn of Imperial College who provided some of the data accompanying the package and supervised me in the writing of it.